@@ -1,3 +1,4 @@
+# to init
 from .covid_news import CoronavirusNews
 from .en_world_news import EnglishWorldNews
 from .protests import Protests
@@ -5,3 +6,4 @@ from .travel import TravelWarnings
 from .terror_monitor import TerrorNews
 from .tr_world_news import TranslatedWorldNews
 from .simple_search import SimpleSearch
+from .hospital_news import HospitalNews
